==> qtjambi-qt3dcore-5.15.3-sources.jar: io/qt/qt3d/core/QPropertyValueRemovedChange.java <==
package io.qt.qt3d.core;


/**
 * <p>Used to notify when a value is added to a property</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueremovedchange.html">Qt3DCore::QPropertyValueRemovedChange</a></p>
 */
public class QPropertyValueRemovedChange extends io.qt.qt3d.core.QStaticPropertyValueRemovedChangeBase
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueremovedchange.html#QPropertyValueRemovedChange">Qt3DCore::QPropertyValueRemovedChange::QPropertyValueRemovedChange(Qt3DCore::QNodeId)</a></p>
     */
    @Deprecated
    public QPropertyValueRemovedChange(io.qt.qt3d.core.QNodeId subjectId){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId);
    }
    
    @Deprecated
    private native static void initialize_native(QPropertyValueRemovedChange instance, io.qt.qt3d.core.QNodeId subjectId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueremovedchange.html#removedValue">Qt3DCore::QPropertyValueRemovedChange::removedValue()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object removedValue(){
        return removedValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object removedValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueremovedchange.html#setRemovedValue">Qt3DCore::QPropertyValueRemovedChange::setRemovedValue(QVariant)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setRemovedValue(java.lang.Object value){
        setRemovedValue_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    @io.qt.QtUninvokable
    private native void setRemovedValue_native_cref_QVariant(long __this__nativeId, java.lang.Object value);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QPropertyValueRemovedChange(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.13-sources.jar: io/qt/qt3d/core/QPropertyValueRemovedChange.java <==
package io.qt.qt3d.core;


/**
 * <p>Used to notify when a value is added to a property</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueremovedchange.html">Qt3DCore::QPropertyValueRemovedChange</a></p>
 */
public class QPropertyValueRemovedChange extends io.qt.qt3d.core.QStaticPropertyValueRemovedChangeBase
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueremovedchange.html#QPropertyValueRemovedChange">Qt3DCore::QPropertyValueRemovedChange::QPropertyValueRemovedChange(Qt3DCore::QNodeId)</a></p>
     */
    @Deprecated
    public QPropertyValueRemovedChange(io.qt.qt3d.core.QNodeId subjectId){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId);
    }
    
    @Deprecated
    private native static void initialize_native(QPropertyValueRemovedChange instance, io.qt.qt3d.core.QNodeId subjectId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueremovedchange.html#removedValue">Qt3DCore::QPropertyValueRemovedChange::removedValue()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object removedValue(){
        return removedValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object removedValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueremovedchange.html#setRemovedValue">Qt3DCore::QPropertyValueRemovedChange::setRemovedValue(QVariant)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setRemovedValue(java.lang.Object value){
        setRemovedValue_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    @io.qt.QtUninvokable
    private native void setRemovedValue_native_cref_QVariant(long __this__nativeId, java.lang.Object value);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QPropertyValueRemovedChange(QPrivateConstructor p) { super(p); } 
    
}
